package CGI::Application::Structured::Tools;

1;


__END__


=head1 NAME

CGI::Application::Structured::Tools

=head1 ABSTRACT

Provides tools and templates to generate and maintain CGI::Application::Structured based web applications.

See the tutorial at L<CGI::Application::Structured> as well as L<scripts/cas-starter.pl>


=cut
